@@ -4,6 +4,7 @@
 from functools import partial
 from typing import Any
 from typing import Dict
+from typing import Iterable
 from typing import List
 from typing import Optional
 from typing import Tuple
@@ -15,10 +16,12 @@ from nptyping import NDArray
 import numpy as np
 from scipy import signal
 
+from .constants import ALL_METRICS
 from .constants import AMPLITUDE_UUID
 from .constants import AUC_UUID
 from .constants import CENTIMILLISECONDS_PER_SECOND
 from .constants import CONTRACTION_VELOCITY_UUID
+from .constants import IRREGULARITY_INTERVAL_UUID
 from .constants import MIN_NUMBER_PEAKS
 from .constants import MIN_NUMBER_VALLEYS
 from .constants import PRIOR_PEAK_INDEX_UUID
@@ -63,15 +66,11 @@ def peak_detector(
     if not twitches_point_up:
         peak_invertor_factor *= -1
         valley_invertor_factor *= -1
-    sampling_period_cms = (
-        filtered_magnetic_signal[0, 1] - filtered_magnetic_signal[0, 0]
-    )
+    sampling_period_cms = filtered_magnetic_signal[0, 1] - filtered_magnetic_signal[0, 0]
     maximum_possible_twitch_frequency = 7  # pylint:disable=invalid-name # (Eli 9/1/20): I can't think of a shorter name to describe this concept fully # Hz
     minimum_required_samples_between_twitches = int(  # pylint:disable=invalid-name # (Eli 9/1/20): I can't think of a shorter name to describe this concept fully
         round(
-            (1 / maximum_possible_twitch_frequency)
-            * CENTIMILLISECONDS_PER_SECOND
-            / sampling_period_cms,
+            (1 / maximum_possible_twitch_frequency) * CENTIMILLISECONDS_PER_SECOND / sampling_period_cms,
             0,
         )
     )
@@ -99,25 +98,28 @@ def peak_detector(
     # TODO Tanner (11/3/20): move this loop to find_twitch_indices
     # Patches error in B6 file for when two valleys are found in a single valley. If this is true left_bases, right_bases, prominences, and raw magnetic sensor data will also be equivalent to their previous value. This if statement indicates that the valley should be disregarded if the interpolated values on left and right intersection points of a horizontal line at the an evaluation height are equivalent. This would mean that the left and right sides of the peak and its neighbor peak align, indicating that it just one peak rather than two.
     # https://docs.scipy.org/doc/scipy/reference/generated/scipy.signal.peak_widths.html#scipy.signal.peak_widths
-    for i in range(1, len(valley_indices)):
+
+    i = 1
+    while i < len(valley_indices):
         if left_ips[i] == left_ips[i - 1] and right_ips[i] == right_ips[i - 1]:
             valley_idx = valley_indices[i]
             valley_idx_last = valley_indices[i - 1]
-            if magnetic_signal[valley_idx_last] == magnetic_signal[valley_idx]:
+
+            if magnetic_signal[valley_idx_last] >= magnetic_signal[valley_idx]:
                 valley_indices = np.delete(valley_indices, i)
-                i -= 1
-            elif magnetic_signal[valley_idx] > magnetic_signal[valley_idx_last]:
-                valley_indices = np.delete(valley_indices, i - 1)
-            else:  # pragma: no cover  # (Anna 3/31/21): we don't have a case as of yet in which the first peak is higher than the second however know that it is possible and therefore aren't worried about code coverage in this case.
-                valley_indices = np.delete(valley_indices, i)  # pragma: no cover
-                i -= 1  # pragma: no cover
+                left_ips = np.delete(left_ips, i)
+                right_ips = np.delete(right_ips, i)
+            else:  # pragma: no cover # (Anna 3/31/21): we don't have a case as of yet in which the first peak is higher than the second however know that it is possible and therefore aren't worried about code coverage in this case.
+                valley_indices = np.delete(valley_indices, i - 1)  # pragma: no cover
+                left_ips = np.delete(left_ips, i - 1)  # pragma: no cover
+                right_ips = np.delete(right_ips, i - 1)  # pragma: no cover
+        else:
+            i += 1
 
     return peak_indices, valley_indices
 
 
-def create_avg_dict(
-    metric: NDArray[int], round_to_int: bool = True
-) -> Dict[str, Union[Float64, int]]:
+def create_avg_dict(metric: NDArray[int], round_to_int: bool = True) -> Dict[str, Union[Float64, int]]:
     """Calculate the average values of a specific metric.
 
     Args:
@@ -127,12 +129,18 @@ def create_avg_dict(
         a dictionary of the average statistics of that metric in which the metrics are the key and average statistics are the value
     """
     dictionary: Dict[str, Union[Float64, int]] = dict()
-
     dictionary["n"] = len(metric)
-    dictionary["mean"] = np.mean(metric)
-    dictionary["std"] = np.std(metric)
-    dictionary["min"] = np.min(metric)
-    dictionary["max"] = np.max(metric)
+    if len(metric) > 0:
+        dictionary["mean"] = np.mean(metric)
+        dictionary["std"] = np.std(metric)
+        dictionary["min"] = np.min(metric)
+        dictionary["max"] = np.max(metric)
+    else:
+        dictionary["mean"] = None
+        dictionary["std"] = None
+        dictionary["min"] = None
+        dictionary["max"] = None
+
     if round_to_int:
         for iter_key in ("mean", "std", "min", "max"):
             dictionary[iter_key] = int(round(dictionary[iter_key]))
@@ -143,16 +151,17 @@ def data_metrics(
     peak_and_valley_indices: Tuple[NDArray[int], NDArray[int]],
     filtered_data: NDArray[(2, Any), int],
     rounded: bool = True,
+    metrics_to_create: Iterable[UUID] = ALL_METRICS,
 ) -> Tuple[
     Dict[
         int,
         Dict[
-            UUID,  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+            UUID,  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
             Union[
                 Dict[int, Dict[UUID, Union[Tuple[int, int], int]]],
                 Union[float, int],
             ],
-        ],  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        ],  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
     ],
     Dict[
         UUID,
@@ -174,9 +183,7 @@ def data_metrics(
         int,
         Dict[
             UUID,
-            Union[
-                Dict[int, Dict[UUID, Union[Tuple[int, int], int]]], Union[float, int]
-            ],
+            Union[Dict[int, Dict[UUID, Union[Tuple[int, int], int]]], Union[float, int]],
         ],
     ] = dict()
     aggregate_dict: Dict[
@@ -184,110 +191,129 @@ def data_metrics(
         Union[Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]],
     ] = dict()
 
-    # create dependent dicitonaries
-    period_averages_dict: Dict[str, Union[float, int]] = {}
-    amplitude_averages_dict: Dict[str, Union[float, int]] = {}
-    auc_averages_dict: Dict[str, Union[float, int]] = {}
-
+    # get values needed for metrics creation
     peak_indices, _ = peak_and_valley_indices
-
-    # find twitch time points
-
-    twitch_indices = find_twitch_indices(peak_and_valley_indices, filtered_data)
+    twitch_indices = find_twitch_indices(peak_and_valley_indices)
     num_twitches = len(twitch_indices)
     time_series = filtered_data[0, :]
 
+    # create top level dict
+    twitch_peak_indices = tuple(twitch_indices.keys())
+    main_twitch_dict = {time_series[twitch_peak_indices[i]]: dict() for i in range(num_twitches)}
+
     # find twitch periods
-    combined_twitch_periods = calculate_twitch_period(
-        twitch_indices, peak_indices, filtered_data
-    )
+    if TWITCH_PERIOD_UUID in metrics_to_create or TWITCH_FREQUENCY_UUID in metrics_to_create:
+        combined_twitch_periods = calculate_twitch_period(twitch_indices, peak_indices, filtered_data)
+    if TWITCH_PERIOD_UUID in metrics_to_create:
+        _add_per_twitch_metrics(main_twitch_dict, TWITCH_PERIOD_UUID, combined_twitch_periods)
+        aggregate_dict[TWITCH_PERIOD_UUID] = create_avg_dict(combined_twitch_periods)
 
-    twitch_frequencies = 1 / (
-        combined_twitch_periods.astype(float) / CENTIMILLISECONDS_PER_SECOND
-    )
-    frequency_averages_dict = create_avg_dict(twitch_frequencies, round_to_int=False)
-
-    # find aggregate values of period data
-    period_averages_dict = create_avg_dict(combined_twitch_periods)
-
-    aggregate_dict[TWITCH_PERIOD_UUID] = period_averages_dict
-    aggregate_dict[TWITCH_FREQUENCY_UUID] = frequency_averages_dict
+    # find twitch frequencies
+    if TWITCH_FREQUENCY_UUID in metrics_to_create:
+        twitch_frequencies = 1 / (combined_twitch_periods.astype(float) / CENTIMILLISECONDS_PER_SECOND)
+        _add_per_twitch_metrics(main_twitch_dict, TWITCH_FREQUENCY_UUID, twitch_frequencies)
+        aggregate_dict[TWITCH_FREQUENCY_UUID] = create_avg_dict(twitch_frequencies, round_to_int=False)
 
     # find twitch amplitudes
-    amplitudes: NDArray[int] = calculate_amplitudes(
-        twitch_indices, filtered_data, round_to_int=rounded
-    )
-
-    # find aggregate values of amplitude data
-    amplitude_averages_dict = create_avg_dict(amplitudes, round_to_int=rounded)
-
-    aggregate_dict[AMPLITUDE_UUID] = amplitude_averages_dict
+    if AMPLITUDE_UUID in metrics_to_create:
+        amplitudes: NDArray[int] = calculate_amplitudes(twitch_indices, filtered_data, round_to_int=rounded)
+        _add_per_twitch_metrics(main_twitch_dict, AMPLITUDE_UUID, amplitudes)
+        aggregate_dict[AMPLITUDE_UUID] = create_avg_dict(amplitudes, round_to_int=rounded)
 
     # find twitch widths
-    widths = calculate_twitch_widths(
-        twitch_indices, filtered_data, round_to_int=rounded
-    )
-    width_stats_dict: Dict[int, Dict[str, Union[float, int]]] = dict()
+    if (
+        WIDTH_UUID in metrics_to_create
+        or CONTRACTION_VELOCITY_UUID in metrics_to_create
+        or RELAXATION_VELOCITY_UUID in metrics_to_create
+    ):
+        widths = calculate_twitch_widths(twitch_indices, filtered_data, round_to_int=rounded)
+    if WIDTH_UUID in metrics_to_create:
+        _add_per_twitch_metrics(main_twitch_dict, WIDTH_UUID, widths)
 
-    for iter_percent in TWITCH_WIDTH_PERCENTS:
-        iter_list_of_width_values: List[Union[float, int]] = []
-        for iter_twitch in widths:
-            iter_width_value = iter_twitch[iter_percent][WIDTH_VALUE_UUID]
-            if not isinstance(iter_width_value, (float, int)):  # making mypy happy
-                raise NotImplementedError(
-                    f"The width value under key {WIDTH_VALUE_UUID} must be a float or an int. It was: {iter_width_value}"
-                )
-            iter_list_of_width_values.append(iter_width_value)
-        iter_stats_dict = create_avg_dict(
-            iter_list_of_width_values, round_to_int=rounded
-        )
-        width_stats_dict[iter_percent] = iter_stats_dict
-
-    aggregate_dict[WIDTH_UUID] = width_stats_dict
-
-    # calculate auc
-    auc_per_twitch: NDArray[int] = calculate_area_under_curve(
-        twitch_indices, filtered_data, widths, round_to_int=rounded
-    )
+        width_stats_dict: Dict[int, Dict[str, Union[float, int]]] = dict()
+        for iter_percent in TWITCH_WIDTH_PERCENTS:
+            iter_list_of_width_values: List[Union[float, int]] = []
+            for iter_twitch in widths:
+                iter_width_value = iter_twitch[iter_percent][WIDTH_VALUE_UUID]
+                if not isinstance(iter_width_value, (float, int)):  # making mypy happy
+                    raise NotImplementedError(
+                        f"The width value under key {WIDTH_VALUE_UUID} must be a float or an int. It was: {iter_width_value}"
+                    )
+                iter_list_of_width_values.append(iter_width_value)
+            iter_stats_dict = create_avg_dict(iter_list_of_width_values, round_to_int=rounded)
+            width_stats_dict[iter_percent] = iter_stats_dict
+        aggregate_dict[WIDTH_UUID] = width_stats_dict
 
     # calculate twitch contraction/relaxation velocities
-    contraction_velocity = calculate_twitch_velocity(twitch_indices, widths, True)
-    contraction_velocity_averages = create_avg_dict(
-        contraction_velocity, round_to_int=False
-    )
-    aggregate_dict[CONTRACTION_VELOCITY_UUID] = contraction_velocity_averages
+    if CONTRACTION_VELOCITY_UUID in metrics_to_create:
+        contraction_velocity = calculate_twitch_velocity(twitch_indices, widths, True)
+        _add_per_twitch_metrics(main_twitch_dict, CONTRACTION_VELOCITY_UUID, contraction_velocity)
+        aggregate_dict[CONTRACTION_VELOCITY_UUID] = create_avg_dict(contraction_velocity, round_to_int=False)
+    if RELAXATION_VELOCITY_UUID in metrics_to_create:
+        relaxation_velocity = calculate_twitch_velocity(twitch_indices, widths, False)
+        _add_per_twitch_metrics(main_twitch_dict, RELAXATION_VELOCITY_UUID, relaxation_velocity)
+        aggregate_dict[RELAXATION_VELOCITY_UUID] = create_avg_dict(relaxation_velocity, round_to_int=False)
 
-    relaxation_velocity = calculate_twitch_velocity(twitch_indices, widths, False)
-    relaxation_velocity_averages = create_avg_dict(
-        relaxation_velocity, round_to_int=False
-    )
-    aggregate_dict[RELAXATION_VELOCITY_UUID] = relaxation_velocity_averages
+    # calculate twitch interval irregularity
+    if IRREGULARITY_INTERVAL_UUID in metrics_to_create:
+        interval_irregularity = calculate_interval_irregularity(twitch_indices, time_series)
+        _add_per_twitch_metrics(main_twitch_dict, IRREGULARITY_INTERVAL_UUID, interval_irregularity)
+        interval_irregularity_averages = create_avg_dict(interval_irregularity[1:-1], round_to_int=False)
+        interval_irregularity_averages["n"] += 2
+        aggregate_dict[IRREGULARITY_INTERVAL_UUID] = interval_irregularity_averages
 
-    # find aggregate values of area under curve data
-    auc_averages_dict = create_avg_dict(auc_per_twitch, round_to_int=rounded)
-
-    aggregate_dict[AUC_UUID] = auc_averages_dict
-
-    # add metrics to per peak dictionary
-    twitch_peak_indices = tuple(twitch_indices.keys())
-    for i in range(num_twitches):
-        main_twitch_dict.update(
-            {
-                time_series[twitch_peak_indices[i]]: {
-                    TWITCH_PERIOD_UUID: combined_twitch_periods[i],
-                    AMPLITUDE_UUID: amplitudes[i],
-                    WIDTH_UUID: widths[i],
-                    AUC_UUID: auc_per_twitch[i],
-                    TWITCH_FREQUENCY_UUID: twitch_frequencies[i],
-                    CONTRACTION_VELOCITY_UUID: contraction_velocity[i],
-                    RELAXATION_VELOCITY_UUID: relaxation_velocity[i],
-                }
-            }
+    # calculate auc
+    if AUC_UUID in metrics_to_create:
+        auc_per_twitch: NDArray[int] = calculate_area_under_curve(
+            twitch_indices, filtered_data, widths, round_to_int=rounded
         )
+        _add_per_twitch_metrics(main_twitch_dict, AUC_UUID, auc_per_twitch)
+        aggregate_dict[AUC_UUID] = create_avg_dict(auc_per_twitch, round_to_int=rounded)
 
     return main_twitch_dict, aggregate_dict
 
 
+def _add_per_twitch_metrics(
+    main_twitch_dict: Dict[Any, Any], metric_id: UUID, metrics: Union[NDArray[int], NDArray[float]]
+) -> None:
+    for i, twitch_dict in enumerate(main_twitch_dict.values()):
+        twitch_dict[metric_id] = metrics[i]
+
+
+def calculate_interval_irregularity(
+    twitch_indices: NDArray[int],
+    time_series: NDArray[(1, Any), int],
+) -> NDArray[float]:
+    """Find the interval irregularity for each twitch.
+
+    Args:
+        twitch_indices: a dictionary in which the key is an integer representing the time points of all the peaks of interest and the value is an inner dictionary with various UUID of prior/subsequent peaks and valleys and their index values.
+        filtered_data: a 2D array (time vs value) of the data
+
+    Returns:
+        an array of floats that are the interval irregularities of each twitch
+    """
+    list_of_twitch_indices = list(twitch_indices.keys())
+    num_twitches = len(list_of_twitch_indices)
+
+    iter_list_of_intervals: List[Union[float, int, None]] = []
+    iter_list_of_intervals.append(None)
+
+    for twitch in range(1, num_twitches - 1):
+        last_twitch_index = list_of_twitch_indices[twitch - 1]
+        current_twitch_index = list_of_twitch_indices[twitch]
+        next_twitch_index = list_of_twitch_indices[twitch + 1]
+
+        last_interval = time_series[current_twitch_index] - time_series[last_twitch_index]
+        current_interval = time_series[next_twitch_index] - time_series[current_twitch_index]
+        interval = abs(current_interval - last_interval)
+
+        iter_list_of_intervals.append(interval)
+
+    iter_list_of_intervals.append(None)
+    return np.asarray(iter_list_of_intervals, dtype=float)
+
+
 def calculate_twitch_velocity(
     twitch_indices: NDArray[int],
     widths: List[
@@ -333,10 +359,7 @@ def calculate_twitch_velocity(
             raise NotImplementedError(
                 f"The width value under twitch {twitch} must be a Tuple. It was: {iter_coord_top}"
             )
-        velocity = abs(
-            (iter_coord_top[1] - iter_coord_base[1])
-            / (iter_coord_top[0] - iter_coord_base[0])
-        )
+        velocity = abs((iter_coord_top[1] - iter_coord_base[1]) / (iter_coord_top[0] - iter_coord_base[0]))
         iter_list_of_velocities.append(velocity)
     return np.asarray(iter_list_of_velocities, dtype=float)
 
@@ -372,7 +395,6 @@ def calculate_twitch_period(
 
 def find_twitch_indices(
     peak_and_valley_indices: Tuple[NDArray[int], NDArray[int]],
-    filtered_data: NDArray[(2, Any), int],
 ) -> Dict[int, Dict[UUID, Optional[int]]]:
     """Find twitches that can be analyzed.
 
@@ -381,7 +403,6 @@ def find_twitch_indices(
 
     Args:
         peak_and_valley_indices: a Tuple of 1D array of integers representing the indices of the peaks and valleys
-        filtered_data: a 2D array of the data after being noise filtered
 
     Returns:
         a dictionary in which the key is an integer representing the time points of all the peaks of interest and the value is an inner dictionary with various UUIDs of prior/subsequent peaks and valleys and their index values.
@@ -401,30 +422,22 @@ def find_twitch_indices(
         if prev_feature_is_peak:
             if valley_indices[valley_idx] > peak_indices[peak_idx]:
                 raise TwoPeaksInARowError(
-                    peak_and_valley_indices,
-                    filtered_data,
                     (peak_indices[peak_idx - 1], peak_indices[peak_idx]),
                 )
             valley_idx += 1
         else:
             if valley_indices[valley_idx] < peak_indices[peak_idx]:
                 raise TwoValleysInARowError(
-                    peak_and_valley_indices,
-                    filtered_data,
                     (valley_indices[valley_idx - 1], valley_indices[valley_idx]),
                 )
             peak_idx += 1
         prev_feature_is_peak = not prev_feature_is_peak
     if peak_idx < len(peak_indices) - 1:
         raise TwoPeaksInARowError(
-            peak_and_valley_indices,
-            filtered_data,
             (peak_indices[peak_idx], peak_indices[peak_idx + 1]),
         )
     if valley_idx < len(valley_indices) - 1:
         raise TwoValleysInARowError(
-            peak_and_valley_indices,
-            filtered_data,
             (valley_indices[valley_idx], valley_indices[valley_idx + 1]),
         )
 
@@ -435,26 +448,16 @@ def find_twitch_indices(
                 continue
 
             twitches[itr_peak_index] = {
-                PRIOR_PEAK_INDEX_UUID: None
-                if itr_idx == 0
-                else peak_indices[itr_idx - 1],
-                PRIOR_VALLEY_INDEX_UUID: valley_indices[
-                    itr_idx - 1 if starts_with_peak else itr_idx
-                ],
+                PRIOR_PEAK_INDEX_UUID: None if itr_idx == 0 else peak_indices[itr_idx - 1],
+                PRIOR_VALLEY_INDEX_UUID: valley_indices[itr_idx - 1 if starts_with_peak else itr_idx],
                 SUBSEQUENT_PEAK_INDEX_UUID: peak_indices[itr_idx + 1],
-                SUBSEQUENT_VALLEY_INDEX_UUID: valley_indices[
-                    itr_idx if starts_with_peak else itr_idx + 1
-                ],
+                SUBSEQUENT_VALLEY_INDEX_UUID: valley_indices[itr_idx if starts_with_peak else itr_idx + 1],
             }
 
-    # print(list(twitches.keys())[0])
-    # print(twitches[list(twitches.keys())[0]])
     return twitches
 
 
-def _too_few_peaks_or_valleys(
-    peak_indices: NDArray[int], valley_indices: NDArray[int]
-) -> None:
+def _too_few_peaks_or_valleys(peak_indices: NDArray[int], valley_indices: NDArray[int]) -> None:
     """Raise an error if there are too few peaks or valleys detected.
 
     Args:
@@ -509,15 +512,9 @@ def calculate_amplitudes(
     amplitude_series = filtered_data[1, :]
     for iter_twitch_peak_idx, iter_twitch_indices_info in twitch_indices.items():
         peak_amplitude = amplitude_series[iter_twitch_peak_idx]
-        prior_amplitude = amplitude_series[
-            iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]
-        ]
-        subsequent_amplitude = amplitude_series[
-            iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]
-        ]
-        amplitude_value = (
-            (peak_amplitude - prior_amplitude) + (peak_amplitude - subsequent_amplitude)
-        ) / 2
+        prior_amplitude = amplitude_series[iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]]
+        subsequent_amplitude = amplitude_series[iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]]
+        amplitude_value = ((peak_amplitude - prior_amplitude) + (peak_amplitude - subsequent_amplitude)) / 2
         if round_to_int:
             amplitude_value = int(round(amplitude_value, 0))
 
@@ -560,15 +557,7 @@ def calculate_twitch_widths(
     twitch_indices: Dict[int, Dict[UUID, Optional[int]]],
     filtered_data: NDArray[(2, Any), int],
     round_to_int: bool = True,
-) -> List[
-    Dict[
-        int,
-        Dict[
-            UUID,
-            Union[Tuple[Union[float, int], Union[float, int]], Union[float, int]],
-        ],
-    ]
-]:
+) -> List[Dict[int, Dict[UUID, Union[Tuple[Union[float, int], Union[float, int]], Union[float, int]],],]]:
     """Determine twitch width between 10-90% down to the nearby valleys.
 
     Args:
@@ -598,12 +587,8 @@ def calculate_twitch_widths(
             ],
         ] = dict()
         peak_value = value_series[iter_twitch_peak_idx]
-        prior_valley_value = value_series[
-            iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]
-        ]
-        subsequent_valley_value = value_series[
-            iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]
-        ]
+        prior_valley_value = value_series[iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]]
+        subsequent_valley_value = value_series[iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]]
 
         rising_amplitude = peak_value - prior_valley_value
         falling_amplitude = peak_value - subsequent_valley_value
@@ -644,12 +629,8 @@ def calculate_twitch_widths(
             width_val = interpolated_falling_timepoint - interpolated_rising_timepoint
             if round_to_int:
                 width_val = int(round(width_val, 0))
-                interpolated_falling_timepoint = int(
-                    round(interpolated_falling_timepoint, 0)
-                )
-                interpolated_rising_timepoint = int(
-                    round(interpolated_rising_timepoint, 0)
-                )
+                interpolated_falling_timepoint = int(round(interpolated_falling_timepoint, 0))
+                interpolated_rising_timepoint = int(round(interpolated_rising_timepoint, 0))
                 rising_threshold = int(round(rising_threshold, 0))
                 falling_threshold = int(round(falling_threshold, 0))
 
@@ -701,25 +682,17 @@ def calculate_area_under_curve(  # pylint:disable=too-many-locals # Eli (9/1/20)
     ):
         # iter_twitch_peak_timepoint = time_series[iter_twitch_peak_idx]
         width_info = per_twitch_widths[iter_twitch_idx]
-        prior_valley_value = value_series[
-            iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]
-        ]
-        subsequent_valley_value = value_series[
-            iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]
-        ]
+        prior_valley_value = value_series[iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]]
+        subsequent_valley_value = value_series[iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]]
         rising_coords = width_info[width_percent][WIDTH_RISING_COORDS_UUID]
         falling_coords = width_info[width_percent][WIDTH_FALLING_COORDS_UUID]
 
-        if not isinstance(
-            rising_coords, tuple
-        ):  # Eli (9/1/20): this appears needed to make mypy happy
+        if not isinstance(rising_coords, tuple):  # Eli (9/1/20): this appears needed to make mypy happy
             raise NotImplementedError(
                 f"Rising coordinates under the key {WIDTH_RISING_COORDS_UUID} must be a tuple."
             )
 
-        if not isinstance(
-            falling_coords, tuple
-        ):  # Eli (9/1/20): this appears needed to make mypy happy
+        if not isinstance(falling_coords, tuple):  # Eli (9/1/20): this appears needed to make mypy happy
             raise NotImplementedError(
                 f"Falling coordinates under the key {WIDTH_FALLING_COORDS_UUID} must be a tuple."
             )
@@ -732,9 +705,7 @@ def calculate_area_under_curve(  # pylint:disable=too-many-locals # Eli (9/1/20)
         # calculate area of rising side
         rising_idx = iter_twitch_peak_idx
         # move to the left from the twitch peak until the threshold is reached
-        while abs(value_series[rising_idx - 1] - prior_valley_value) > abs(
-            rising_y - prior_valley_value
-        ):
+        while abs(value_series[rising_idx - 1] - prior_valley_value) > abs(rising_y - prior_valley_value):
             left_x = time_series[rising_idx - 1]
             right_x = time_series[rising_idx]
             left_y = value_series[rising_idx - 1]
